( cd usr/lib ; rm -rf libIntelXvMC.so.1 )
( cd usr/lib ; ln -sf libIntelXvMC.so.1.0.0 libIntelXvMC.so.1 )
( cd usr/lib ; rm -rf libI810XvMC.so.1 )
( cd usr/lib ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so.1 )
( cd usr/lib ; rm -rf libI810XvMC.so )
( cd usr/lib ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so )
( cd usr/lib ; rm -rf libIntelXvMC.so )
( cd usr/lib ; ln -sf libIntelXvMC.so.1.0.0 libIntelXvMC.so )
